from setuptools import setup

setup(name='simple_distributions_v11',
      version='1.1',
      description='Gaussian and Binomial distributions',
      packages=['simple_distributions_v11'],
      author = 'Aram hamidi',
      author_email = 'aram1hamidi@gmail.com',
      zip_safe=False)
